from django.contrib import admin
from addressbook.models import Country, Address


@admin.register(Country)
class CountryAdmin(admin.ModelAdmin):
    list_display = ("iso_code", "name")


@admin.register(Address)
class AddressAdmin(admin.ModelAdmin):
    list_display = ("contact_name", "address_one", "county", "country", "is_deleted")
    list_filter = ("is_deleted",)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2023-04-19 15:46
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Address",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(auto_now_add=True, verbose_name="created"),
                ),
                (
                    "modified",
                    models.DateTimeField(auto_now=True, verbose_name="modified"),
                ),
                (
                    "contact_name",
                    models.CharField(max_length=50, verbose_name="contact name"),
                ),
                (
                    "address_one",
                    models.CharField(max_length=50, verbose_name="address one"),
                ),
                (
                    "address_two",
                    models.CharField(
                        blank=True, max_length=50, verbose_name="address two"
                    ),
                ),
                ("town", models.CharField(max_length=50, verbose_name="town")),
                (
                    "county",
                    models.CharField(blank=True, max_length=50, verbose_name="county"),
                ),
                ("postcode", models.CharField(max_length=50, verbose_name="postcode")),
                (
                    "status",
                    models.IntegerField(
                        choices=[(0, b"Active"), (1, b"Display only"), (2, b"Deleted")],
                        default=0,
                        verbose_name="status",
                    ),
                ),
            ],
            options={
                "ordering": ["created"],
                "get_latest_by": "created",
                "verbose_name": "address",
                "verbose_name_plural": "addresses",
            },
        ),
        migrations.CreateModel(
            name="Country",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "iso_code",
                    models.CharField(
                        max_length=2, unique=True, verbose_name="ISO code"
                    ),
                ),
                ("name", models.CharField(max_length=60, verbose_name="name")),
            ],
            options={
                "ordering": ["name"],
                "verbose_name": "country",
                "verbose_name_plural": "countries",
            },
        ),
        migrations.AddField(
            model_name="address",
            name="country",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="addressbook.Country",
                verbose_name="country",
            ),
        ),
    ]



# Generated by Django 2.1.15 on 2023-04-27 06:00

from django.db import migrations, models
from django.utils import timezone


def migrate_to_is_deleted(apps, schema_editor):
    Address = apps.get_model("addressbook", "Address")

    for address in Address.objects.all():
        if address.status == 2:
            address.is_deleted = True
            address.save(update_fields=("is_deleted",))


def migrate_from_is_deleted(apps, schema_editor):
    Address = apps.get_model("addressbook", "Address")

    for address in Address.objects.all():
        if address.is_deleted:
            address.status = 2
            address.save(update_fields=("status",))


class Migration(migrations.Migration):
    dependencies = [
        ("addressbook", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="address",
            name="country",
            field=models.ForeignKey(
                on_delete=models.PROTECT,
                to="addressbook.Country",
                verbose_name="country",
            ),
        ),
        migrations.AlterField(
            model_name="address",
            name="created",
            field=models.DateTimeField(default=timezone.now, editable=False),
        ),
        migrations.AlterField(
            model_name="address",
            name="modified",
            field=models.DateTimeField(default=timezone.now, editable=False),
        ),
        migrations.AddField(
            model_name="address",
            name="is_deleted",
            field=models.BooleanField(default=False, verbose_name="is deleted"),
        ),
        migrations.RunPython(migrate_to_is_deleted, migrate_from_is_deleted),
        migrations.RemoveField(
            model_name="address",
            name="status",
        ),
    ]



from datetime import datetime

from django.db import models
from django.utils import timezone
from django.utils.safestring import mark_safe
from django.utils.encoding import force_str
from django.utils.translation import gettext_lazy as _

from addressbook.conf import settings


class Country(models.Model):
    iso_code = models.CharField(_("ISO code"), max_length=2, unique=True)
    name = models.CharField(_("name"), max_length=60)

    def __str__(self):
        return self.name

    class Meta:
        ordering = ["name"]
        verbose_name = _("country")
        verbose_name_plural = _("countries")


class TimeStampedModel(models.Model):
    created = models.DateTimeField(default=timezone.now, editable=False)
    modified = models.DateTimeField(default=timezone.now, editable=False)

    def save(self, *args, **kwargs):
        if not self.pk:
            self.created = timezone.now()
        self.modified = timezone.now()
        return super(TimeStampedModel, self).save(*args, **kwargs)

    class Meta:
        abstract = True


class Address(TimeStampedModel):
    contact_name = models.CharField(_("contact name"), max_length=50)
    address_one = models.CharField(_("address one"), max_length=50)
    address_two = models.CharField(_("address two"), max_length=50, blank=True)
    town = models.CharField(_("town"), max_length=50)
    county = models.CharField(_("county"), max_length=50, blank=True)
    postcode = models.CharField(_("postcode"), max_length=50)
    country = models.ForeignKey(
        Country, verbose_name=_("country"), on_delete=models.PROTECT
    )
    is_deleted = models.BooleanField(_("is deleted"), default=False)

    def __init__(self, *args, **kwargs):
        if settings.NORMALISE_TO_UPPER:
            for field in self._meta.get_fields():
                if isinstance(field, models.CharField):
                    try:
                        kwargs[field.name] = kwargs[field.name].upper()
                    except KeyError:
                        pass
        super(Address, self).__init__(*args, **kwargs)

    def __str__(self):
        return self.contact_name

    def _output_html(self, template, separator):
        output = []
        rows = (
            self.contact_name,
            self.address_one,
            self.address_two,
            self.town,
            self.county,
            self.postcode,
            self.country,
        )
        for row in rows:
            if row:
                output.append(template % {"field": force_str(row)})
        return mark_safe(separator.join(output))

    def as_p(self):
        return self._output_html("%(field)s", "<br />\n")

    def save(self, *args, **kwargs):
        if settings.NORMALISE_TO_UPPER:
            for field in self._meta.get_fields():
                if isinstance(field, models.CharField):
                    setattr(self, field.name, getattr(self, field.name).upper())
        super(Address, self).save(*args, **kwargs)

    class Meta:
        ordering = ["created"]
        verbose_name = _("address")
        verbose_name_plural = _("addresses")
        get_latest_by = "created"


class AddressField(models.ForeignKey):
    def __init__(self, **kwargs):
        kwargs.setdefault("to", Address)
        kwargs.setdefault("on_delete", models.PROTECT)
        super().__init__(**kwargs)



#!/usr/bin/env python
from distutils.core import setup

VERSION = __import__("addressbook").VERSION

setup(
    author="Simon Luijk",
    author_email="simon@simonluijk.com",
    name="django-addresses",
    version=VERSION,
    description="Some forms around a few models to manage addresses",
    url="https://github.com/simonluijk/django-addresses",
    packages=[
        "addressbook",
        "addressbook.conf",
        "addressbook.migrations",
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Utilities",
    ],
)
